@@ -23,6 +23,7 @@ using SubpathKey = QString;
 using ResourceList = QList<ResourceId>;
 using AppList = QList<AppId>;
 using SubpathList = QList<SubpathKey>;
+using UserInfo = QPair<QString, int>;
 
 static const QString &SUFFIX = QString(".json");
 constexpr int ConfigUserRole = Qt::UserRole + 10;
@@ -211,6 +212,12 @@ static QString qvariantToString(const QVariant &v)
     return doc.isNull() ? v.toString() : doc.toJson();
 }
 
+static QString qvariantToStringCompact(const QVariant &v)
+{
+    const auto &doc = QJsonDocument::fromVariant(v);
+    return doc.isNull() ? v.toString() : doc.toJson(QJsonDocument::Compact);
+}
+
 static QVariant stringToQVariant(const QString &s)
 {
     QJsonParseError error;
@@ -224,7 +231,7 @@ static QStringList translationDirs()
 {
     QStringList result;
     result << QCoreApplication::applicationDirPath();
-    for (auto item : Dtk::Core::DStandardPaths::standardLocations(QStandardPaths::DataLocation)) {
+    for (auto item : Dtk::Core::DStandardPaths::standardLocations(QStandardPaths::AppLocalDataLocation)) {
         result << item + "/translations";
     };
     return result;
@@ -240,3 +247,24 @@ static void loadTranslation(const QString &fileName)
         }
     }
 }
+
+static QList<UserInfo> fetchUserInfos()
+{
+    QList<UserInfo> res;
+    QFile file("/etc/passwd");
+    if (!file.open(QIODevice::ReadOnly)) {
+        return {};
+    }
+    while (!file.atEnd()) {
+        QByteArray line = file.readLine();
+        const auto user = line.split(':');
+        if (user.count() != 7)
+            continue;
+        const auto loginin = user.at(6);
+        if (loginin.contains("nologin"))
+            continue;
+
+        res << UserInfo{user[0], user[2].toInt()};
+    }
+    return res;
+}
