@@ -196,6 +196,16 @@ void OEMDialog::saveOverridesFiles(const QString &dirName)
     }
 }
 
+static QString escapeCsvField(const QString &field) {
+    bool needsQuotes = field.contains(',') || field.contains('"') || field.contains('\n');
+    QString escaped = field;
+    escaped.replace("\"", "\"\"");
+    if (needsQuotes) {
+        escaped = "\"" + escaped + "\"";
+    }
+    return escaped;
+}
+
 void OEMDialog::saveCSVFile(const QString &dirName)
 {
     QString fileName = dirName + "/" + "data.csv";
@@ -210,12 +220,11 @@ void OEMDialog::saveCSVFile(const QString &dirName)
                 if (!item->data(SubpathRole).toString().isEmpty()) {
                     path.append(item->data(SubpathRole).toString());
                 }
-                QString content = QString("%1, %2, %3, %4, %5").arg(item->data(AppidRole).toString())
-                                                     .arg(item->data(ResourceRole).toString())
-                                                     .arg(item->data(KeyRole).toString())
-                                                     .arg(item->data(ValueRole).toString())
-                                                     .arg(path);
-                out << content << "\n";
+                out << escapeCsvField(item->data(AppidRole).toString()) << ",";
+                out << escapeCsvField(item->data(ResourceRole).toString()) << ",";
+                out << escapeCsvField(item->data(KeyRole).toString()) << ",";
+                out << escapeCsvField(qvariantToStringCompact(item->data(ValueRole))) << ",";
+                out << escapeCsvField(path) << "\n";
             }
         }
         out.flush();
@@ -257,7 +266,7 @@ void OEMDialog::displayChangedResult()
             model->appendRow(QList<QStandardItem*>() << new DStandardItem(item->data(AppidRole).toString())
                              << new DStandardItem(item->data(ResourceRole).toString())
                              << new DStandardItem(item->data(KeyRole).toString())
-                             << new DStandardItem(item->data(ValueRole).toString())
+                             << new DStandardItem(qvariantToString(item->data(ValueRole)))
                              << new DStandardItem(path));
         }
     }
@@ -347,7 +356,12 @@ QWidget *OEMDialog::getItemWidget(ConfigGetter *getter, DStandardItem *item)
     bool canWrite = !(flags & Dtk::Core::DConfigFile::Flag::NoOverride);
     QVariant v = item->data(ValueRole);
     QWidget *valueWidget = nullptr;
-    if (v.type() == QVariant::Bool) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const auto valueType = v.type();
+#else
+    const auto valueType = v.typeId();
+#endif
+    if (valueType == QVariant::Bool) {
         auto btn = new DSwitchButton();
         btn->setChecked(v.toBool());
         btn->setEnabled(canWrite);
@@ -363,7 +377,7 @@ QWidget *OEMDialog::getItemWidget(ConfigGetter *getter, DStandardItem *item)
         hlayout->addWidget(btn);
 
         valueWidget = widget;
-    } else if (v.type() == QVariant::Double) {
+    } else if (valueType == QVariant::Double) {
         auto widget = new DDoubleSpinBox();
         widget->setRange(std::numeric_limits<double>::min(), std::numeric_limits<double>::max());
         widget->setValue(v.toDouble());
@@ -375,10 +389,10 @@ QWidget *OEMDialog::getItemWidget(ConfigGetter *getter, DStandardItem *item)
         valueWidget = widget;
     } else {
         auto widget = new DLineEdit();
-        widget->setText(v.toString());
+        widget->setText(qvariantToString(v));
         widget->setEnabled(canWrite);
         connect(widget, &DLineEdit::textChanged, widget, [this, item](const QString &text){
-            item->setData(text, ValueRole);
+            item->setData(stringToQVariant(text), ValueRole);
             treeItemChanged(item);
         });
         valueWidget = widget;
